@@ -26,8 +26,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gconf/gconf-client.h>
 
-#define TETRIS_VERSION "1.2.5"
-
 extern int LINES;
 extern int COLUMNS;
 
@@ -128,6 +126,7 @@ private:
 	void initOptions ();
 	void setOptions ();
 	void writeOptions ();
+        void setupScoreState ();
 	
 	GdkPixbuf *image;
 	GdkPixbuf *bgimage;
@@ -156,6 +155,10 @@ private:
 
 	bool fastFall;
 	int fastFallPoints;
+        bool dropBlock;
+
+        GnomeCanvasItem * pauseMessage;
+        GnomeCanvasItem * gameoverMessage;
 };
 
 #endif // __tetris_h__
